@@ -1,10 +1,12 @@
-from abc import ABC, abstractmethod
 from typing import Dict, Any
+from abc import ABC, abstractmethod
 from pathlib import PurePath
 import clease
-from clease_gui import WidgetStyleMixin, AppDataKeys
+from clease_gui.style_mixin import WidgetStyleMixin
+from clease_gui.app_data import AppDataKeys
+from clease_gui.event_context import EventContextManager, log_error
 
-__all__ = ['BaseDashboard']
+__all__ = ["BaseDashboard"]
 
 
 class BaseDashboard(WidgetStyleMixin, ABC):
@@ -44,10 +46,12 @@ class BaseDashboard(WidgetStyleMixin, ABC):
 
     def log_error(self, logger, *args, **kwargs) -> None:
         """Log as exception if we're in dev mode, otherwise only log as error"""
-        if self.dev_mode:
-            logger.exception(*args, **kwargs)
-        else:
-            logger.error(*args, **kwargs)
+        log_error(*args, logger=logger, dev_mode=self.dev_mode, **kwargs)
+
+    def event_context(self, logger=None) -> EventContextManager:
+        """Context where events which shouldn't
+        crash the GUI even on an exception are run"""
+        return EventContextManager(logger=logger, dev_mode=self.dev_mode)
 
     @abstractmethod
     def initialize(self) -> None:
@@ -59,14 +63,13 @@ class BaseDashboard(WidgetStyleMixin, ABC):
 
     @property
     def settings(self) -> clease.settings.ClusterExpansionSettings:
-        """Short-cut for accessing settings, since this is a common operation."""
+        """Short-cut for accessing settings, since this is a common operation.
+        Raises a KeyError if it doesn't exist."""
         try:
             return self.app_data[self.KEYS.SETTINGS]
         except KeyError:
             # Raise a better message
-            raise KeyError(
-                'No settings present. Create/load a settings object first.'
-            ) from None
+            raise KeyError("No settings present. Create/load a settings object first.") from None
 
     def get_db_name(self) -> PurePath:
         """Return the DB name form the settings, and prepend the current
