@@ -411,7 +411,7 @@ class CanonicalMC(BaseDashboard):
         if _step_val != "off":
             self.step_move_obs = observers.MoveObserver(atoms, only_accept=_step_val)
             mc.attach(self.step_move_obs)
-        self.app_data["_mc_step_obs"] = self.step_move_obs
+        self.app_data[self.KEYS.STEP_OBSERVER] = self.step_move_obs
 
         # Initialize the progress bar
         self.mc_progress.value = 0
