@@ -234,13 +234,16 @@ class SupercellDashboard(BaseDashboard):
         for ii, indices in enumerate(index_by_basis):
             new_syms = []
             for elem in basis_elements[ii]:
-                new_syms.append
                 new_count = species_per_basis[ii].get(elem, 0)
                 new_syms.extend([elem] * new_count)
             assert len(new_syms) == len(indices), (len(new_syms), len(indices))
             # Shuffle sublattice
             random.shuffle(new_syms)
             atoms.symbols[indices] = new_syms
+
+        # Check if we violate concentration constraints. We do not update if that's the case.
+        if not self.settings.concentration.is_valid(index_by_basis, atoms):
+            raise ValueError("The specified configuration violates the concentration constraints.")
         # We don't need to redraw the species output widgets again
         self.set_supercell(atoms, draw_species_output=False)
         logger.info("Supercell updated.")
